# Changelog

<!-- towncrier release notes start -->

## 0.1.1 (2024-04-10)


### Documentation

- update documentation link [#9](https://github.com/fleetingbytes/human-regex/issues/9)

## 0.1.0 (2024-04-10)


### New Features

- Initial release [#7](https://github.com/fleetingbytes/human-regex/issues/7)
